@@ -171,9 +171,7 @@ void k9call::updateQuery()
 
 	QStringList qlist = m_SearchString.split("0", QString::SkipEmptyParts);
 	QSet<QContactLocalId> set;
-	if(qlist.empty())
-		set = m_FirstNameTrie.lookup ( m_SearchString.data() );
-	else {
+	if(!qlist.empty()) {
 		set = m_FirstNameTrie.lookup ( qlist[0].data() );
 		if(qlist.size() == 1) {
 			// There isn't a space, so just look up for last names
@@ -185,7 +183,7 @@ void k9call::updateQuery()
 		}
 	}
 
-	if(set.count() < 15 && set.count() > 0) {
+	if(set.count() > 0) {
 		m_ActiveList = QList<QContactLocalId>::fromSet(set);
 
 		if(m_Manager == NULL)
@@ -350,12 +348,16 @@ bool k9call::doesPhoneNumberExist(QContact *i_Contact)
 void k9call::call()
 {
 	// Update accelerator
-	QPair<QContactLocalId, QContactLocalId>& accel = m_Accel[m_SearchString];
-	QContactLocalId id = *m_ActiveListItr;
-	if(accel.first == 0 || accel.second == id)
-		accel.first = id;
-	else
-		accel.second = id;
+	QString search = m_SearchString;
+	while(!search.isEmpty()) {
+		QPair<QContactLocalId, QContactLocalId>& accel = m_Accel[search];
+		QContactLocalId id = *m_ActiveListItr;
+		if(accel.first == 0 || accel.second == id)
+			accel.first = id;
+		else
+			accel.second = id;
+		search.truncate(search.length()-1);
+	}
 
 	// You want to dial whatever number is shown to the user
 	QString number = ui.phoneNumber->text();
